# Minimal Example

`minimal.xml` is a one-page article that should be your first exercise in setting up MathBook XML.  Look at the top of the file for instructions on processing the file into a variety of output formats.
